==> pm4py-1.0.9.tar.gz: pm4py-1.0.9/pm4py/visualization/sna/factory.py <==
from pm4py.visualization.sna.versions import networkx, pyviz

NETWORKX = "networkx"
PYVIZ = "pyviz"

VERSIONS_APPLY = {NETWORKX: networkx.apply, PYVIZ: pyviz.apply}
VERSIONS_VIEW = {NETWORKX: networkx.view, PYVIZ: pyviz.view}
VERSIONS_SAVE = {NETWORKX: networkx.save, PYVIZ: pyviz.save}


def apply(mco, rsc_rsc_matrix, parameters=None, variant=NETWORKX):
    """
    Perform SNA visualization starting from the Matrix Container object
    and the Resource-Resource matrix

    Parameters
    -------------
    mco
        Matrix container object
    rsc_rsc_matrix
        Resource-resource matrix
    parameters
        Possible parameters of the algorithm, including:
            weight_threshold: the weight threshold to use in displaying the graph
            directed: indicates if the graph has to be drawn directed
            format: format of the output image (png, svg ...)

    Returns
    -------------
    temp_file_name
        Name of a temporary file where the visualization is placed
    """
    return VERSIONS_APPLY[variant](mco, rsc_rsc_matrix, parameters=parameters)


def view(temp_file_name, parameters=None, variant=NETWORKX):
    """
    View the SNA visualization on the screen

    Parameters
    -------------
    temp_file_name
        Temporary file name
    parameters
        Possible parameters of the algorithm
    """
    return VERSIONS_VIEW[variant](temp_file_name, parameters=parameters)


def save(temp_file_name, dest_file, parameters=None, variant=NETWORKX):
    """
    Save the SNA visualization from a temporary file to a well-defined destination file

    Parameters
    -------------
    temp_file_name
        Temporary file name
    dest_file
        Destination file
    parameters
        Possible parameters of the algorithm
    """
    return VERSIONS_SAVE[variant](temp_file_name, dest_file, parameters=parameters)

==> pm4py-1.0.13.tar.gz: pm4py-1.0.13/pm4py/visualization/sna/factory.py <==
from pm4py.visualization.sna.versions import networkx, pyvis

NETWORKX = "networkx"
PYVIS = "pyvis"

VERSIONS_APPLY = {NETWORKX: networkx.apply, PYVIS: pyvis.apply}
VERSIONS_VIEW = {NETWORKX: networkx.view, PYVIS: pyvis.view}
VERSIONS_SAVE = {NETWORKX: networkx.save, PYVIS: pyvis.save}


def apply(mco, rsc_rsc_matrix, parameters=None, variant=NETWORKX):
    """
    Perform SNA visualization starting from the Matrix Container object
    and the Resource-Resource matrix

    Parameters
    -------------
    mco
        Matrix container object
    rsc_rsc_matrix
        Resource-resource matrix
    parameters
        Possible parameters of the algorithm, including:
            weight_threshold: the weight threshold to use in displaying the graph
            directed: indicates if the graph has to be drawn directed
            format: format of the output image (png, svg ...)

    Returns
    -------------
    temp_file_name
        Name of a temporary file where the visualization is placed
    """
    return VERSIONS_APPLY[variant](mco, rsc_rsc_matrix, parameters=parameters)


def view(temp_file_name, parameters=None, variant=NETWORKX):
    """
    View the SNA visualization on the screen

    Parameters
    -------------
    temp_file_name
        Temporary file name
    parameters
        Possible parameters of the algorithm
    """
    return VERSIONS_VIEW[variant](temp_file_name, parameters=parameters)


def save(temp_file_name, dest_file, parameters=None, variant=NETWORKX):
    """
    Save the SNA visualization from a temporary file to a well-defined destination file

    Parameters
    -------------
    temp_file_name
        Temporary file name
    dest_file
        Destination file
    parameters
        Possible parameters of the algorithm
    """
    return VERSIONS_SAVE[variant](temp_file_name, dest_file, parameters=parameters)
